==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/TreemapNodeStyleMappingDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { TreemapNodeStyleDescription } from "./TreemapNodeStyleDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var TreemapNodeStyleMappingDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TreemapNodeStyleMappingDescription, _super);
    function TreemapNodeStyleMappingDescription() {
        var _this = _super.call(this) || this;
        _this.a1 = null;
        _this.av = 0;
        _this.au = 0;
        _this.ay = null;
        _this.a0 = null;
        return _this;
    }
    TreemapNodeStyleMappingDescription.prototype.get_type = function () {
        return "TreemapNodeStyleMapping";
    };
    Object.defineProperty(TreemapNodeStyleMappingDescription.prototype, "targetType", {
        get: function () {
            return this.a1;
        },
        set: function (a) {
            this.a1 = a;
            this.e("TargetType");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreemapNodeStyleMappingDescription.prototype, "minimumValue", {
        get: function () {
            return this.av;
        },
        set: function (a) {
            this.av = a;
            this.e("MinimumValue");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreemapNodeStyleMappingDescription.prototype, "maximumValue", {
        get: function () {
            return this.au;
        },
        set: function (a) {
            this.au = a;
            this.e("MaximumValue");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreemapNodeStyleMappingDescription.prototype, "value", {
        get: function () {
            return this.ay;
        },
        set: function (a) {
            this.ay = a;
            this.e("Value");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreemapNodeStyleMappingDescription.prototype, "mappingMode", {
        get: function () {
            return this.a0;
        },
        set: function (a) {
            this.a0 = a;
            this.e("MappingMode");
        },
        enumerable: true,
        configurable: true
    });
    TreemapNodeStyleMappingDescription.$t = markType(TreemapNodeStyleMappingDescription, 'TreemapNodeStyleMappingDescription', TreemapNodeStyleDescription.$);
    return TreemapNodeStyleMappingDescription;
}(TreemapNodeStyleDescription));
export { TreemapNodeStyleMappingDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/TreemapNodeStyleMappingDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { TreemapNodeStyleDescription } from "./TreemapNodeStyleDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var TreemapNodeStyleMappingDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TreemapNodeStyleMappingDescription, _super);
    function TreemapNodeStyleMappingDescription() {
        var _this = _super.call(this) || this;
        _this.a9 = null;
        _this.a3 = 0;
        _this.a2 = 0;
        _this.a6 = null;
        _this.a8 = null;
        return _this;
    }
    TreemapNodeStyleMappingDescription.prototype.get_type = function () {
        return "TreemapNodeStyleMapping";
    };
    Object.defineProperty(TreemapNodeStyleMappingDescription.prototype, "targetType", {
        get: function () {
            return this.a9;
        },
        set: function (a) {
            this.a9 = a;
            this.g("TargetType");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreemapNodeStyleMappingDescription.prototype, "minimumValue", {
        get: function () {
            return this.a3;
        },
        set: function (a) {
            this.a3 = a;
            this.g("MinimumValue");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreemapNodeStyleMappingDescription.prototype, "maximumValue", {
        get: function () {
            return this.a2;
        },
        set: function (a) {
            this.a2 = a;
            this.g("MaximumValue");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreemapNodeStyleMappingDescription.prototype, "value", {
        get: function () {
            return this.a6;
        },
        set: function (a) {
            this.a6 = a;
            this.g("Value");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreemapNodeStyleMappingDescription.prototype, "mappingMode", {
        get: function () {
            return this.a8;
        },
        set: function (a) {
            this.a8 = a;
            this.g("MappingMode");
        },
        enumerable: false,
        configurable: true
    });
    TreemapNodeStyleMappingDescription.$t = markType(TreemapNodeStyleMappingDescription, 'TreemapNodeStyleMappingDescription', TreemapNodeStyleDescription.$);
    return TreemapNodeStyleMappingDescription;
}(TreemapNodeStyleDescription));
export { TreemapNodeStyleMappingDescription };
